///<reference path="../../../.d.ts"/>
"use strict";
var ListDevicesCommand = (function () {
    function ListDevicesCommand($devicesServices, $logger, $stringParameter, $options) {
        this.$devicesServices = $devicesServices;
        this.$logger = $logger;
        this.$stringParameter = $stringParameter;
        this.$options = $options;
        this.allowedParameters = [this.$stringParameter];
    }
    ListDevicesCommand.prototype.execute = function (args) {
        var _this = this;
        return (function () {
            var index = 1;
            _this.$devicesServices.initialize({ platform: args[0], deviceId: null, skipInferPlatform: true }).wait();
            var action;
            if (_this.$options.json) {
                _this.$logger.setLevel("ERROR");
                action = function (device) {
                    return (function () {
                        _this.$logger.out(JSON.stringify({
                            identifier: device.getIdentifier(),
                            platform: device.getPlatform(),
                            model: device.getModel(),
                            name: device.getDisplayName(),
                            version: device.getVersion(),
                            vendor: device.getVendor()
                        }));
                    }).future()();
                };
            }
            else {
                action = function (device) {
                    return (function () { _this.$logger.out("%s: '%s'", (index++).toString(), device.getDisplayName(), device.getPlatform(), device.getIdentifier()); }).future()();
                };
            }
            _this.$devicesServices.execute(action, undefined, { allowNoDevices: true }).wait();
        }).future()();
    };
    return ListDevicesCommand;
})();
exports.ListDevicesCommand = ListDevicesCommand;
$injector.registerCommand("device|*list", ListDevicesCommand);
var ListAndroidDevicesCommand = (function () {
    function ListAndroidDevicesCommand($injector, $devicePlatformsConstants) {
        this.$injector = $injector;
        this.$devicePlatformsConstants = $devicePlatformsConstants;
        this.allowedParameters = [];
    }
    ListAndroidDevicesCommand.prototype.execute = function (args) {
        var _this = this;
        return (function () {
            var listDevicesCommand = _this.$injector.resolve(ListDevicesCommand);
            var platform = _this.$devicePlatformsConstants.Android;
            listDevicesCommand.execute([platform]).wait();
        }).future()();
    };
    return ListAndroidDevicesCommand;
})();
$injector.registerCommand("device|android", ListAndroidDevicesCommand);
var ListiOSDevicesCommand = (function () {
    function ListiOSDevicesCommand($injector, $devicePlatformsConstants) {
        this.$injector = $injector;
        this.$devicePlatformsConstants = $devicePlatformsConstants;
        this.allowedParameters = [];
    }
    ListiOSDevicesCommand.prototype.execute = function (args) {
        var _this = this;
        return (function () {
            var listDevicesCommand = _this.$injector.resolve(ListDevicesCommand);
            var platform = _this.$devicePlatformsConstants.iOS;
            listDevicesCommand.execute([platform]).wait();
        }).future()();
    };
    return ListiOSDevicesCommand;
})();
$injector.registerCommand("device|ios", ListiOSDevicesCommand);
